@@ -1,13 +1,13 @@
 {
-#define VEC_LOOP(expr) for(j = 0; j < VECTOR_SIZE; j++) {       \
-        expr;                                       \
+#define VEC_LOOP(expr) for(j = 0; j < BLOCK_SIZE; j++) {       \
+        expr;                                   \
     }
 #define VEC_ARG1(expr)                          \
     BOUNDS_CHECK(store_in);                     \
     BOUNDS_CHECK(arg1);                         \
     {                                           \
-        char *dest = params.mem[store_in];      \
-        char *x1 = params.mem[arg1];            \
+        char *dest = mem[store_in];             \
+        char *x1 = mem[arg1];                   \
         intp ss1 = params.memsizes[arg1];       \
         intp sb1 = params.memsteps[arg1];       \
         /* nowarns is defined and used so as to \
@@ -22,15 +22,15 @@
     BOUNDS_CHECK(arg1);                         \
     BOUNDS_CHECK(arg2);                         \
     {                                           \
-        char *dest = params.mem[store_in];      \
-        char *x1 = params.mem[arg1];            \
+        char *dest = mem[store_in];             \
+        char *x1 = mem[arg1];                   \
         intp ss1 = params.memsizes[arg1];       \
         intp sb1 = params.memsteps[arg1];       \
         /* nowarns is defined and used so as to \
         avoid compiler warnings about unused    \
         variables */                            \
         intp nowarns = ss1+sb1+*x1;             \
-        char *x2 = params.mem[arg2];            \
+        char *x2 = mem[arg2];                   \
         intp ss2 = params.memsizes[arg2];       \
         intp sb2 = params.memsteps[arg2];       \
         nowarns += ss2+sb2+*x2;                 \
@@ -43,18 +43,18 @@
     BOUNDS_CHECK(arg2);                         \
     BOUNDS_CHECK(arg3);                         \
     {                                           \
-        char *dest = params.mem[store_in];      \
-        char *x1 = params.mem[arg1];            \
+        char *dest = mem[store_in];             \
+        char *x1 = mem[arg1];                   \
         intp ss1 = params.memsizes[arg1];       \
         intp sb1 = params.memsteps[arg1];       \
         /* nowarns is defined and used so as to \
         avoid compiler warnings about unused    \
         variables */                            \
         intp nowarns = ss1+sb1+*x1;             \
-        char *x2 = params.mem[arg2];            \
+        char *x2 = mem[arg2];                   \
         intp ss2 = params.memsizes[arg2];       \
         intp sb2 = params.memsteps[arg2];       \
-        char *x3 = params.mem[arg3];            \
+        char *x3 = mem[arg3];                   \
         intp ss3 = params.memsizes[arg3];       \
         intp sb3 = params.memsteps[arg3];       \
         nowarns += ss2+sb2+*x2;                 \
@@ -66,9 +66,9 @@
     BOUNDS_CHECK(store_in);                     \
     BOUNDS_CHECK(arg1);                         \
     {                                           \
-        char *dest = params.mem[store_in];      \
-        char *x1 = params.mem[arg1];            \
-	expr;                                   \
+        char *dest = mem[store_in];             \
+        char *x1 = mem[arg1];                   \
+        expr;                                   \
     } break
 
 #define VEC_ARG2_VML(expr)                      \
@@ -76,9 +76,9 @@
     BOUNDS_CHECK(arg1);                         \
     BOUNDS_CHECK(arg2);                         \
     {                                           \
-        char *dest = params.mem[store_in];      \
-        char *x1 = params.mem[arg1];            \
-        char *x2 = params.mem[arg2];            \
+        char *dest = mem[store_in];             \
+        char *x1 = mem[arg1];                   \
+        char *x2 = mem[arg2];                   \
         expr;                                   \
     } break
 
@@ -88,26 +88,27 @@
     BOUNDS_CHECK(arg2);                         \
     BOUNDS_CHECK(arg3);                         \
     {                                           \
-        char *dest = params.mem[store_in];      \
-        char *x1 = params.mem[arg1];            \
-        char *x2 = params.mem[arg2];            \
-        char *x3 = params.mem[arg3];            \
+        char *dest = mem[store_in];             \
+        char *x1 = mem[arg1];                   \
+        char *x2 = mem[arg2];                   \
+        char *x3 = mem[arg3];                   \
         expr;                                   \
     } break
 
 
     unsigned int pc, j, k, r;
+
     /* set up pointers to next block of inputs and outputs */
-    params.mem[0] = params.output + index * params.memsteps[0];
+    mem[0] = params.output + index * params.memsteps[0];
     for (r = 0; r < params.n_inputs; r++) {
         struct index_data id = params.index_data[r+1];
         if (id.count) {
-            params.mem[1+r] = params.inputs[r];
-            for (j = 0; j < VECTOR_SIZE; j++) {
+            mem[1+r] = params.inputs[r];
+            for (j = 0; j < BLOCK_SIZE; j++) {
                 unsigned int flatindex = 0;
                 for (k = 0; k < id.count; k ++)
                     flatindex += id.strides[k] * id.index[k];
-                memcpy(params.mem[1+r]+ (j*id.size), id.buffer + flatindex, id.size);
+                memcpy(mem[1+r] + (j*id.size), id.buffer + flatindex, id.size);
                 k = id.count - 1;
                 id.index[k] += 1;
                 if (id.index[k] >= id.shape[k])
@@ -119,11 +120,11 @@
                     }
             }
         } else {
-            params.mem[1+r] = params.inputs[r] + index * params.memsteps[1+r];
+            mem[1+r] = params.inputs[r] + index * params.memsteps[1+r];
         }
     }
 
-    /* WARNING: From now on, only do references to params.mem[arg[123]]
+    /* WARNING: From now on, only do references to mem[arg[123]]
        & params.memsteps[arg[123]] inside the VEC_ARG[123] macros,
        or you will risk accessing invalid addresses.  */
 
@@ -173,7 +174,7 @@
         #define c3r   ((double *)(x3+j*sb3))[0]
         #define c3i   ((double *)(x3+j*sb3))[1]
         #define s3    ((char   *)x3+j*sb3)
-	/* Some temporaries */
+        /* Some temporaries */
         double da, db;
         cdouble ca, cb;
         char *ptr;
@@ -199,6 +200,7 @@
 
         case OP_EQ_BBB: VEC_ARG2(b_dest = (b1 == b2));
         case OP_NE_BBB: VEC_ARG2(b_dest = (b1 != b2));
+        case OP_WHERE_BBBB: VEC_ARG3(b_dest = b1 ? b2 : b3);
 
         case OP_GT_BII: VEC_ARG2(b_dest = (i1 > i2));
         case OP_GE_BII: VEC_ARG2(b_dest = (i1 >= i2));
@@ -225,7 +227,8 @@
         case OP_EQ_BSS: VEC_ARG2(b_dest = (stringcmp(s1, s2, ss1, ss2) == 0));
         case OP_NE_BSS: VEC_ARG2(b_dest = (stringcmp(s1, s2, ss1, ss2) != 0));
 
-        case OP_ONES_LIKE_II: VEC_ARG1(i_dest = 1);
+        case OP_CAST_IB: VEC_ARG1(i_dest = (int)(b1));
+        case OP_ONES_LIKE_I: VEC_ARG1(i_dest = 1);
         case OP_NEG_II: VEC_ARG1(i_dest = -i1);
 
         case OP_ADD_III: VEC_ARG2(i_dest = i1 + i2);
@@ -238,8 +241,8 @@
         case OP_WHERE_IBII: VEC_ARG3(i_dest = b1 ? i2 : i3);
 
         case OP_CAST_LI: VEC_ARG1(l_dest = (long long)(i1));
-        case OP_ONES_LIKE_LL: VEC_ARG1(l_dest = 1);
-        case OP_NEG_LL: VEC_ARG1(l_dest = -i1);
+        case OP_ONES_LIKE_L: VEC_ARG1(l_dest = 1);
+        case OP_NEG_LL: VEC_ARG1(l_dest = -l1);
 
         case OP_ADD_LLL: VEC_ARG2(l_dest = l1 + l2);
         case OP_SUB_LLL: VEC_ARG2(l_dest = l1 - l2);
@@ -253,7 +256,7 @@
           /* Float */
         case OP_CAST_FI: VEC_ARG1(f_dest = (float)(i1));
         case OP_CAST_FL: VEC_ARG1(f_dest = (float)(l1));
-        case OP_ONES_LIKE_FF: VEC_ARG1(f_dest = 1.0);
+        case OP_ONES_LIKE_F: VEC_ARG1(f_dest = 1.0);
         case OP_NEG_FF: VEC_ARG1(f_dest = -f1);
 
         case OP_ADD_FFF: VEC_ARG2(f_dest = f1 + f2);
@@ -261,50 +264,50 @@
         case OP_MUL_FFF: VEC_ARG2(f_dest = f1 * f2);
         case OP_DIV_FFF:
 #ifdef USE_VML
-	    VEC_ARG2_VML(vsDiv(VECTOR_SIZE,
+            VEC_ARG2_VML(vsDiv(BLOCK_SIZE,
                                (float*)x1, (float*)x2, (float*)dest));
 #else
-	    VEC_ARG2(f_dest = f1 / f2);
+            VEC_ARG2(f_dest = f1 / f2);
 #endif
         case OP_POW_FFF:
 #ifdef USE_VML
-	    VEC_ARG2_VML(vsPow(VECTOR_SIZE,
+            VEC_ARG2_VML(vsPow(BLOCK_SIZE,
                                (float*)x1, (float*)x2, (float*)dest));
 #else
-	    VEC_ARG2(f_dest = powf(f1, f2));
+            VEC_ARG2(f_dest = powf(f1, f2));
 #endif
         case OP_MOD_FFF: VEC_ARG2(f_dest = f1 - floorf(f1/f2) * f2);
 
         case OP_SQRT_FF:
 #ifdef USE_VML
-	    VEC_ARG1_VML(vsSqrt(VECTOR_SIZE, (float*)x1, (float*)dest));
+            VEC_ARG1_VML(vsSqrt(BLOCK_SIZE, (float*)x1, (float*)dest));
 #else
-	    VEC_ARG1(f_dest = sqrtf(f1));
+            VEC_ARG1(f_dest = sqrtf(f1));
 #endif
 
         case OP_WHERE_FBFF: VEC_ARG3(f_dest = b1 ? f2 : f3);
 
-        case OP_FUNC_FF:
+        case OP_FUNC_FFN:
 #ifdef USE_VML
-	    VEC_ARG1_VML(functions_ff_vml[arg2](VECTOR_SIZE,
+            VEC_ARG1_VML(functions_ff_vml[arg2](BLOCK_SIZE,
                                                 (float*)x1, (float*)dest));
 #else
-	    VEC_ARG1(f_dest = functions_ff[arg2](f1));
+            VEC_ARG1(f_dest = functions_ff[arg2](f1));
 #endif
-        case OP_FUNC_FFF:
+        case OP_FUNC_FFFN:
 #ifdef USE_VML
-	    VEC_ARG2_VML(functions_fff_vml[arg3](VECTOR_SIZE,
+            VEC_ARG2_VML(functions_fff_vml[arg3](BLOCK_SIZE,
                                                  (float*)x1, (float*)x2,
                                                  (float*)dest));
 #else
-	    VEC_ARG2(f_dest = functions_fff[arg3](f1, f2));
+            VEC_ARG2(f_dest = functions_fff[arg3](f1, f2));
 #endif
 
           /* Double */
         case OP_CAST_DI: VEC_ARG1(d_dest = (double)(i1));
         case OP_CAST_DL: VEC_ARG1(d_dest = (double)(l1));
         case OP_CAST_DF: VEC_ARG1(d_dest = (double)(f1));
-        case OP_ONES_LIKE_DD: VEC_ARG1(d_dest = 1.0);
+        case OP_ONES_LIKE_D: VEC_ARG1(d_dest = 1.0);
         case OP_NEG_DD: VEC_ARG1(d_dest = -d1);
 
         case OP_ADD_DDD: VEC_ARG2(d_dest = d1 + d2);
@@ -312,43 +315,43 @@
         case OP_MUL_DDD: VEC_ARG2(d_dest = d1 * d2);
         case OP_DIV_DDD:
 #ifdef USE_VML
-	    VEC_ARG2_VML(vdDiv(VECTOR_SIZE,
+            VEC_ARG2_VML(vdDiv(BLOCK_SIZE,
                                (double*)x1, (double*)x2, (double*)dest));
 #else
-	    VEC_ARG2(d_dest = d1 / d2);
+            VEC_ARG2(d_dest = d1 / d2);
 #endif
         case OP_POW_DDD:
 #ifdef USE_VML
-	    VEC_ARG2_VML(vdPow(VECTOR_SIZE,
+            VEC_ARG2_VML(vdPow(BLOCK_SIZE,
                                (double*)x1, (double*)x2, (double*)dest));
 #else
-	    VEC_ARG2(d_dest = pow(d1, d2));
+            VEC_ARG2(d_dest = pow(d1, d2));
 #endif
         case OP_MOD_DDD: VEC_ARG2(d_dest = d1 - floor(d1/d2) * d2);
 
         case OP_SQRT_DD:
 #ifdef USE_VML
-	    VEC_ARG1_VML(vdSqrt(VECTOR_SIZE, (double*)x1, (double*)dest));
+            VEC_ARG1_VML(vdSqrt(BLOCK_SIZE, (double*)x1, (double*)dest));
 #else
-	    VEC_ARG1(d_dest = sqrt(d1));
+            VEC_ARG1(d_dest = sqrt(d1));
 #endif
 
         case OP_WHERE_DBDD: VEC_ARG3(d_dest = b1 ? d2 : d3);
 
-        case OP_FUNC_DD:
+        case OP_FUNC_DDN:
 #ifdef USE_VML
-	    VEC_ARG1_VML(functions_dd_vml[arg2](VECTOR_SIZE,
+            VEC_ARG1_VML(functions_dd_vml[arg2](BLOCK_SIZE,
                                                 (double*)x1, (double*)dest));
 #else
-	    VEC_ARG1(d_dest = functions_dd[arg2](d1));
+            VEC_ARG1(d_dest = functions_dd[arg2](d1));
 #endif
-        case OP_FUNC_DDD:
+        case OP_FUNC_DDDN:
 #ifdef USE_VML
-	    VEC_ARG2_VML(functions_ddd_vml[arg3](VECTOR_SIZE,
+            VEC_ARG2_VML(functions_ddd_vml[arg3](BLOCK_SIZE,
                                                  (double*)x1, (double*)x2,
                                                  (double*)dest));
 #else
-	    VEC_ARG2(d_dest = functions_ddd[arg3](d1, d2));
+            VEC_ARG2(d_dest = functions_ddd[arg3](d1, d2));
 #endif
 
             /* Complex */
@@ -360,7 +363,7 @@
                                   ci_dest = 0);
         case OP_CAST_CD: VEC_ARG1(cr_dest = d1;
                                   ci_dest = 0);
-        case OP_ONES_LIKE_CC: VEC_ARG1(cr_dest = 1;
+        case OP_ONES_LIKE_C: VEC_ARG1(cr_dest = 1;
                                   ci_dest = 0);
         case OP_NEG_CC: VEC_ARG1(cr_dest = -c1r;
                                  ci_dest = -c1i);
@@ -370,42 +373,42 @@
         case OP_SUB_CCC: VEC_ARG2(cr_dest = c1r - c2r;
                                   ci_dest = c1i - c2i);
         case OP_MUL_CCC: VEC_ARG2(da = c1r*c2r - c1i*c2i;
-				  ci_dest = c1r*c2i + c1i*c2r;
-				  cr_dest = da);
+                                  ci_dest = c1r*c2i + c1i*c2r;
+                                  cr_dest = da);
         case OP_DIV_CCC:
 #ifdef USE_VMLXXX /* VML complex division is slower */
-	    VEC_ARG2_VML(vzDiv(VECTOR_SIZE, (const MKL_Complex16*)x1,
+            VEC_ARG2_VML(vzDiv(BLOCK_SIZE, (const MKL_Complex16*)x1,
                                (const MKL_Complex16*)x2, (MKL_Complex16*)dest));
 #else
-	    VEC_ARG2(da = c2r*c2r + c2i*c2i;
-		     db = (c1r*c2r + c1i*c2i) / da;
-		     ci_dest = (c1i*c2r - c1r*c2i) / da;
-		     cr_dest = db);
+            VEC_ARG2(da = c2r*c2r + c2i*c2i;
+                     db = (c1r*c2r + c1i*c2i) / da;
+                     ci_dest = (c1i*c2r - c1r*c2i) / da;
+                     cr_dest = db);
 #endif
         case OP_EQ_BCC: VEC_ARG2(b_dest = (c1r == c2r && c1i == c2i));
         case OP_NE_BCC: VEC_ARG2(b_dest = (c1r != c2r || c1i != c2i));
 
         case OP_WHERE_CBCC: VEC_ARG3(cr_dest = b1 ? c2r : c3r;
                                      ci_dest = b1 ? c2i : c3i);
-        case OP_FUNC_CC:
+        case OP_FUNC_CCN:
 #ifdef USE_VML
-	    VEC_ARG1_VML(functions_cc_vml[arg2](VECTOR_SIZE,
+            VEC_ARG1_VML(functions_cc_vml[arg2](BLOCK_SIZE,
                                                 (const MKL_Complex16*)x1,
                                                 (MKL_Complex16*)dest));
 #else
-	    VEC_ARG1(ca.real = c1r;
-		     ca.imag = c1i;
-		     functions_cc[arg2](&ca, &ca);
-		     cr_dest = ca.real;
-		     ci_dest = ca.imag);
+            VEC_ARG1(ca.real = c1r;
+                     ca.imag = c1i;
+                     functions_cc[arg2](&ca, &ca);
+                     cr_dest = ca.real;
+                     ci_dest = ca.imag);
 #endif
-        case OP_FUNC_CCC: VEC_ARG2(ca.real = c1r;
-                                   ca.imag = c1i;
-                                   cb.real = c2r;
-                                   cb.imag = c2i;
-                                   functions_ccc[arg3](&ca, &cb, &ca);
-                                   cr_dest = ca.real;
-                                   ci_dest = ca.imag);
+        case OP_FUNC_CCCN: VEC_ARG2(ca.real = c1r;
+                                    ca.imag = c1i;
+                                    cb.real = c2r;
+                                    cb.imag = c2i;
+                                    functions_ccc[arg3](&ca, &cb, &ca);
+                                    cr_dest = ca.real;
+                                    ci_dest = ca.imag);
 
         case OP_REAL_DC: VEC_ARG1(d_dest = c1r);
         case OP_IMAG_DC: VEC_ARG1(d_dest = c1i);
@@ -436,6 +439,7 @@
         }
     }
 
+
 #undef VEC_LOOP
 #undef VEC_ARG1
 #undef VEC_ARG2
@@ -480,3 +484,9 @@
 #undef c3i
 #undef s3
 }
+
+/*
+Local Variables:
+   c-basic-offset: 4
+End:
+*/
