@@ -211,7 +211,9 @@ class test_evaluate(TestCase):
         else:
             self.fail()
 
-    def test_changing_nthreads_inc(self):
+    # Execution order set here so as to not use too many threads
+    # during the rest of the execution.  See #33 for details.
+    def test_changing_nthreads_00_inc(self):
         a = linspace(-1, 1, 1e6)
         b = ((.25*a + .75)*a - 1.5)*a - 2
         for nthreads in range(1,7):
@@ -219,10 +221,10 @@ class test_evaluate(TestCase):
             c = evaluate("((.25*a + .75)*a - 1.5)*a - 2")
             assert_array_almost_equal(b, c)
 
-    def test_changing_nthreads_dec(self):
+    def test_changing_nthreads_01_dec(self):
         a = linspace(-1, 1, 1e6)
         b = ((.25*a + .75)*a - 1.5)*a - 2
-        for nthreads in range(6, 0):
+        for nthreads in range(6, 1, -1):
             numexpr.set_num_threads(nthreads)
             c = evaluate("((.25*a + .75)*a - 1.5)*a - 2")
             assert_array_almost_equal(b, c)
@@ -237,7 +239,9 @@ tests = [
           '2*a + arctan2(a, b)',
           'arcsin(0.5)',
           'where(a != 0.0, 2, a)',
+          'where(a > 10, b < a, b > a)',
           'where((a-10).real != 0.0, a, 2)',
+          '0.25 * (a < 5) + 0.33 * (a >= 5)',
           'cos(1+1)',
           '1+1',
           '1',
@@ -548,18 +552,46 @@ class test_irregular_stride(TestCase):
         assert_array_equal(f0[i0], arange(5, dtype=int32))
         assert_array_equal(f1[i1], arange(5, dtype=float64))
 
+
 # Case test for threads
 class test_threading(TestCase):
-    def test_select(self):
+    def test_thread(self):
         import threading
         class ThreadTest(threading.Thread):
             def run(self):
                 a = arange(3)
                 assert_array_equal(evaluate('a**3'), array([0, 1, 8]))
-
         test = ThreadTest()
         test.start()
 
+# The worker function for the subprocess (needs to be here because Windows
+# has problems pickling nested functions with the multiprocess module :-/)
+def _worker(qout = None):
+    ra = numpy.arange(1e3)
+    rows = evaluate('ra > 0')
+    #print "Succeeded in evaluation!\n"
+    if qout is not None:
+        qout.put("Done")
+
+# Case test for subprocesses (via multiprocessing module)
+class test_subprocess(TestCase):
+    def test_multiprocess(self):
+        import multiprocessing as mp
+        # Check for two threads at least
+        numexpr.set_num_threads(2)
+        #print "**** Running from main process:"
+        _worker()
+        #print "**** Running from subprocess:"
+        qout = mp.Queue()
+        ps = mp.Process(target=_worker, args=(qout,))
+        ps.daemon = True
+        ps.start()
+
+        result = qout.get()
+        #print result
+
+
+
 
 def print_versions():
     """Print the versions of software that numexpr relies on."""
@@ -615,7 +647,12 @@ def suite():
         theSuite.addTest(unittest.makeSuite(test_strings))
         theSuite.addTest(
             unittest.makeSuite(test_irregular_stride) )
-        theSuite.addTest(unittest.makeSuite(test_threading, prefix='check'))
+        theSuite.addTest(unittest.makeSuite(test_subprocess))
+        # I need to put this test after test_subprocess because
+        # if not, the test suite locks immediately before test_subproces.
+        # This only happens with Windows, so I suspect of a subtle bad
+        # interaction with threads and subprocess :-/
+        theSuite.addTest(unittest.makeSuite(test_threading))
 
     return theSuite
 
