@@ -1,3 +1,6 @@
+import os
+
+from numexpr.interpreter import _set_num_threads
 from numexpr import use_vml
 
 if use_vml:
@@ -60,6 +63,46 @@ def set_vml_num_threads(nthreads):
         _set_vml_num_threads(nthreads)
 
 
+def set_num_threads(nthreads):
+    """
+    Sets a number of threads to be used in operations.
+
+    Returns the previous setting for the number of threads.
+
+    During initialization time Numexpr sets this number to the number
+    of detected cores in the system (see `detect_number_of_cores()`).
+
+    If you are using Intel's VML, you may want to use
+    `set_vml_num_threads(nthreads)` to perform the parallel job with
+    VML instead.  However, you should get very similar performance
+    with VML-optimized functions, and VML's parallelizer cannot deal
+    with common expresions like `(x+1)*(x-2)`, while Numexpr's one
+    can.
+    """
+    old_nthreads = _set_num_threads(nthreads)
+
+
+def detect_number_of_cores():
+    """
+    Detects the number of cores on a system. Cribbed from pp.
+    """
+    # Linux, Unix and MacOS:
+    if hasattr(os, "sysconf"):
+        if os.sysconf_names.has_key("SC_NPROCESSORS_ONLN"):
+            # Linux & Unix:
+            ncpus = os.sysconf("SC_NPROCESSORS_ONLN")
+            if isinstance(ncpus, int) and ncpus > 0:
+                return ncpus
+        else: # OSX:
+            return int(os.popen2("sysctl -n hw.ncpu")[1].read())
+    # Windows:
+    if os.environ.has_key("NUMBER_OF_PROCESSORS"):
+        ncpus = int(os.environ["NUMBER_OF_PROCESSORS"]);
+        if ncpus > 0:
+            return ncpus
+    return 1 # Default
+
+
 class CacheDict(dict):
     """
     A dictionary that prevents itself from growing too much.
